Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(438)

Unified Diff: firmware/lib/vboot_firmware.c

Issue 2865014: Assorted integration fixes. (Closed) Base URL: ssh://gitrw.chromium.org/vboot_reference.git
Patch Set: Add struct size tests Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « firmware/lib/include/vboot_struct.h ('k') | firmware/lib/vboot_kernel.c » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: firmware/lib/vboot_firmware.c
diff --git a/firmware/lib/vboot_firmware.c b/firmware/lib/vboot_firmware.c
index 2fb1f6cc7b692c0af80d55c6da4b85571f3f7ddf..36f09c9159fa4d04ae7d7cbf1f09169284aa1339 100644
--- a/firmware/lib/vboot_firmware.c
+++ b/firmware/lib/vboot_firmware.c
@@ -55,8 +55,8 @@ int LoadFirmware(LoadFirmwareParams* params) {
return LOAD_FIRMWARE_RECOVERY;
/* Initialize the TPM and read rollback indices. */
- /* TODO: fix SetupTPM parameter */
- if (0 != SetupTPM(0, 0) )
+ /* TODO: fix SetupTPM parameter for developer mode */
+ if (0 != SetupTPM(RO_NORMAL_MODE, 0) )
return LOAD_FIRMWARE_RECOVERY;
if (0 != GetStoredVersions(FIRMWARE_VERSIONS,
&tpm_key_version, &tpm_fw_version))
@@ -204,6 +204,9 @@ int LoadFirmware(LoadFirmwareParams* params) {
* is cleared only by TPM_Init at reboot. */
if (0 != LockFirmwareVersions())
return LOAD_FIRMWARE_RECOVERY;
+
+ /* Success */
+ return LOAD_FIRMWARE_SUCCESS;
}
/* If we're still here, no good firmware, so go to recovery mode. */
« no previous file with comments | « firmware/lib/include/vboot_struct.h ('k') | firmware/lib/vboot_kernel.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698